from decimal import Decimal
from fractions import Fraction
from itertools import (combinations, combinations_with_replacement,
                       permutations, product)
from math import *
from statistics import *

from pymath import *
